inlp (innovata Natural Language Processing)


- NLTK
- KoNLPy (https://pypi.org/project/konlpy/)


사전작업
- ROOT_PATH 를 OS-환경변수로 수동으로 저장.
: export ROOT_PATH=your_root_path

임시방편 작업 (PyPI 패키지 정식 등록 전)
- LIB_PATH 를 OS-환경변수로 수동으로 저장.
: export LIB_PATH=~/libs
